@@ -16,7 +16,7 @@ variables, with optional initialization from named file.
 
 __all__ = ('Env', 'Path', 'pyCompat', )
 
-VERSION = '1.0.0'
+VERSION = '1.1.0'
 __author__ = 'Vitaly Protsko'
 __version__ = tuple(VERSION.split('.'))
 
@@ -193,13 +193,17 @@ class Env(object):
   filename = None
   filepath = None
 
+  IGNORE = 0
+  UPPER  = 1
+  LOWER  = 2
+
   # "private"
   nodata = NoValue()
   truestr = ('true', 'on', 'ok', 'y', 'yes', 'yea', '1') 
 
 
   def __init__(self, **defaults):
-    for item in ('defconf_key', 'filepath', 'filename'):
+    for item in ('defconf_key', 'filepath', 'filename', 'case'):
       if item in defaults:
         setattr(Env, item, defaults[item])
         del defaults[item]
@@ -213,25 +217,40 @@ class Env(object):
     setattr(self, '__iter__', Env.data.__iter__)
 
 
-  def __contains__(self, var):
-    return var in self.data
+  def update(self, **kw):
+    self.defaults.update(kw)
 
+  def makecase(self, var):
+    try:
+      mode = object.__getattribute__(self, 'case')
+      if mode == Env.IGNORE: return var
+      if mode == Env.UPPER:  return var.upper()
+      if mode == Env.LOWER:  return var.lower()
+    except Exception as e:
+      pass
+    return var
+
+
+  def __contains__(self, var):
+    return self.makecase(var) in self.data
 
   def __getattr__(self, key):
-    if key in self.data: return self(key)
-    return object.__getattr__(self, key)
+    casekey = self.makecase(key)
+    if casekey in self.data: return self(casekey)
+    return object.__getattribute__(self, key)
 
   def __setattr__(self, key, val):
-    if key in self.data:
-      self.data[key] = val
+    casekey = self.makecase(key)
+    if casekey in self.data:
+      self.data[casekey] = val
     else:
       object.__setattr__(self, key, val)
 
   def __getitem__(self, key):
-    return self(key)
+    return self(self.makecase(key))
 
   def __setitem__(self, key, val):
-    self.data[key] = val
+    self.data[self.makecase(key)] = val
 
 
   def __call__(self, var, cast=None, default=nodata, parse_default=False):
@@ -244,6 +263,7 @@ class Env(object):
 
     :returns: Value from environment or default (if set)
     """
+    var = self.makecase(var)
 
     isDefault = False
     if var in self.defaults:
